@@ -19,6 +19,8 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
+# pylint: disable=wrong-import-position
+
 # keyboardinterrupt should simply terminate
 # import signal
 # signal.signal(signal.SIGINT, signal.SIG_DFL)
@@ -26,7 +28,7 @@ import sys
 import logging
 
 from qt import QObject, usingQt4
-from kde import ki18n, KApplication, KCmdLineArgs, KCmdLineOptions
+from kde import ki18n, KApplication, KCmdLineArgs, KCmdLineOptions, KGlobal
 from about import About
 
 from common import Options, SingleshotOptions, Internal, Debug, unicodeString
@@ -34,7 +36,6 @@ from util import kprint
 
 # do not import modules using twisted before our reactor is running
 
-
 def initRulesets():
     """exits if user only wanted to see available rulesets"""
     import predefined  # pylint: disable=unused-variable
@@ -100,9 +101,6 @@ def defineOptions():
     options.add(
         "port <PORT>",
         ki18n("use a dedicated server listening on PORT. Intended only for testing"))
-    options.add(
-        "server3",
-        ki18n("start the server using Python 3. Meant only for testing."))
     options.add("debug <OPTIONS>", ki18n(Debug.help()))
     return options
 
@@ -112,7 +110,6 @@ def parseOptions():
     args = KCmdLineArgs.parsedArgs()
     Internal.app = APP
     Options.playOpen |= args.isSet('playopen')
-    Options.server3 |= args.isSet('server3')
     Options.showRulesets |= args.isSet('rulesets')
     Options.rulesetName = str(args.getOption('ruleset'))
     if args.isSet('host'):
@@ -120,7 +117,7 @@ def parseOptions():
     if args.isSet('player'):
         Options.player = unicodeString(args.getOption('player'))
     if args.isSet('rounds'):
-        Options.rounds = str(args.getOption('rounds'))
+        Options.rounds = int(args.getOption('rounds'))
     if args.isSet('ai'):
         Options.AI = str(args.getOption('ai'))
     if args.isSet('csv'):
@@ -171,6 +168,9 @@ if __name__ == "__main__":
     APP = KApplication()
     parseOptions()
 
+    if Debug.neutral:
+        KGlobal.locale().setLanguage('en_US')
+
     if Debug.events:
         EVHANDLER = EvHandler()
         APP.installEventFilter(EVHANDLER)
@@ -181,7 +181,7 @@ if __name__ == "__main__":
     if Options.csv:
         if gitHead() == 'current':
             Internal.logger.debug(
-                'You cannot write to %s with changes uncommitted to git' %
+                'You cannot write to %s with changes uncommitted to git',
                 Options.csv)
             sys.exit(2)
     from mainwindow import MainWindow
